<?php

namespace Modules\Parametros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Method;
use Zeedhi\Framework\DataSource\DataSet;
use Exception;

class ParametrosSupplyTekController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $crudService;
    protected $dataSourceManager;
  	protected $connection;
  	protected $fileServerURL;
  	protected $imgPathURL;
  	protected $zhFileUploader;
  	protected $uploadRoutes;
	

    public function __construct($crudService,  $environment, $dataSourceManager, $connection, $fileServerURL, $imgPathURL, $zhFileUploader, $uploadRoutes) {
        $this->crudService       = $crudService;
        $this->environment       = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->connection        = $connection;
        $this->fileServerURL     = $fileServerURL;
        $this->imgPathURL = $imgPathURL;
        $this->zhFileUploader    = $zhFileUploader;
        $this->uploadRoutes     = $uploadRoutes;
    }
    
    public function saveSupplyTek(DTO\Request\Row $request, DTO\Response $response)
  	{
  		try {
        $row = $request->getRow();
        if($row['LOGO'] != null){
		        if(isset($row["IMAGE_UPLOAD"])){
      	        $fileRow['LOGO_SUPPLY_UPLOAD'][0] = [
                      'b64File'            => $row["IMAGE_UPLOAD"][0]["b64File"],
                      "name"               => $row["IMAGE_UPLOAD"][0]["name"],
                      'type'               => $row["IMAGE_UPLOAD"][0]["type"],
                      'webkitRelativePath' => '',
                      'size'               => ''
                  ];
        	        $this->zhFileUploader->uploadFilesInRow($fileRow, $this->uploadRoutes['/supply/uploadLogo']['fileField'], $this->uploadRoutes['/supply/uploadLogo']['customFolder']);
    		        $row["DSPATHFOTO"] = $fileRow['LOGO_SUPPLY_UPLOAD']["0"]["path"];
		        }
		    } else {
		      $row["DSPATHFOTO"] = null;
		    }
  			$this->updateSupplyTek($row);
  			$response->addMessage(new Message("Operação realizada com sucesso."));
  		} catch (\Exception $e) {
  			$response->setError(new Error($e->getMessage(), 500));
  		}
  	}
	
    public function updateSupplyTek($row){
      $sql = "UPDATE PARASUPRI 
              SET IDALTERAQTDE   = :P_IDALTERAQTDE,
                  IDALTPRODAPROV = :P_IDALTPRODAPROV,
                  IDUTLORCAMENTO = :P_IDUTLORCAMENTO,
                  IDCONSVALPREC  = :P_IDCONSVALPREC,
                  DSDIRLOGOMARCA = :P_DSDIRLOGOMARCA
              WHERE CDFILIAL = :P_CDFILIAL 
                AND NRORG    = :P_NRORG";
      $stmt = $this->connection->prepare($sql);
      $stmt->execute(
          array(
              'P_IDALTERAQTDE'   => $row['IDALTERAQTDE'],
              'P_IDALTPRODAPROV' => $row['IDALTPRODAPROV'],
              'P_IDUTLORCAMENTO' => $row['IDUTLORCAMENTO'],
              'P_IDCONSVALPREC'  => $row['IDCONSVALPREC'],
              "P_DSDIRLOGOMARCA" => $row['DSPATHFOTO'],
              'P_CDFILIAL'       => $row['CDFILIAL'],
              'P_NRORG'          => $this->environment->getNrorg()
          )   
      );
    }
    
    public function getImgPathURL(DTO\Request\Row $request, DTO\Response $response)
  	{
  		try {
  		  $ImgURL = $this->imgPathURL;
  		  $dataset = array(
                "IMAGEURL"   => $ImgURL
            );
  			$response->addDataSet(new DataSet('imgPathURL', $dataset));
  		} catch (\Exception $e) {
  			$response->setError(new Error($e->getMessage(), 500));
  		}
  	}
}